@@ -5,7 +5,7 @@ describe 'aodh::policy' do
   shared_examples_for 'aodh policies' do
     let :params do
       {
-        :policy_path => '/etc/aodh/policy.json',
+        :policy_path => '/etc/aodh/policy.yaml',
         :policies    => {
           'context_is_admin' => {
             'key'   => 'context_is_admin',
@@ -17,11 +17,14 @@ describe 'aodh::policy' do
 
     it 'set up the policies' do
       is_expected.to contain_openstacklib__policy__base('context_is_admin').with({
-        :key   => 'context_is_admin',
-        :value => 'foo:bar'
+        :key         => 'context_is_admin',
+        :value       => 'foo:bar',
+        :file_user   => 'root',
+        :file_group  => 'aodh',
+        :file_format => 'yaml',
       })
       is_expected.to contain_oslo__policy('aodh_config').with(
-        :policy_file => '/etc/aodh/policy.json',
+        :policy_file => '/etc/aodh/policy.yaml',
       )
     end
   end
@@ -37,5 +40,4 @@ describe 'aodh::policy' do
       it_configures 'aodh policies'
     end
   end
-
 end
